# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKFastMarchingPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkFastMarchingUpwindGradientImageFilterPython
else:
    import _itkFastMarchingUpwindGradientImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkIndexPython
import itk.itkSizePython
import itk.pyBasePython
import itk.itkOffsetPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.vnl_vectorPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkVectorPython
import itk.itkPointPython
import itk.itkImagePython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBAPixelPython
import itk.itkImageRegionPython
import itk.itkRGBPixelPython
import itk.ITKFastMarchingBasePython
import itk.itkFastMarchingStoppingCriterionBasePython
import itk.itkNodePairPython
import itk.itkLevelSetNodePython
import itk.itkImageToImageFilterAPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkFastMarchingImageFilterPython
class itkFastMarchingUpwindGradientImageFilterEnums(object):
    r"""Proxy of C++ itkFastMarchingUpwindGradientImageFilterEnums class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    TargetCondition_NoTargets = _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterEnums_TargetCondition_NoTargets
    
    TargetCondition_OneTarget = _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterEnums_TargetCondition_OneTarget
    
    TargetCondition_SomeTargets = _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterEnums_TargetCondition_SomeTargets
    
    TargetCondition_AllTargets = _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterEnums_TargetCondition_AllTargets
    

    def __init__(self, *args):
        r"""
        __init__(self) -> itkFastMarchingUpwindGradientImageFilterEnums
        __init__(self, arg0) -> itkFastMarchingUpwindGradientImageFilterEnums

        Parameters
        ----------
        arg0: itkFastMarchingUpwindGradientImageFilterEnums const &

        """
        _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterEnums_swiginit(self, _itkFastMarchingUpwindGradientImageFilterPython.new_itkFastMarchingUpwindGradientImageFilterEnums(*args))
    __swig_destroy__ = _itkFastMarchingUpwindGradientImageFilterPython.delete_itkFastMarchingUpwindGradientImageFilterEnums

# Register itkFastMarchingUpwindGradientImageFilterEnums in _itkFastMarchingUpwindGradientImageFilterPython:
_itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterEnums_swigregister(itkFastMarchingUpwindGradientImageFilterEnums)

def itkFastMarchingUpwindGradientImageFilterIF2IF2_New():
    return itkFastMarchingUpwindGradientImageFilterIF2IF2.New()

class itkFastMarchingUpwindGradientImageFilterIF2IF2(itk.itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF2IF2):
    r"""Proxy of C++ itkFastMarchingUpwindGradientImageFilterIF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkFastMarchingUpwindGradientImageFilterIF2IF2_Pointer"""
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkFastMarchingUpwindGradientImageFilterIF2IF2_Pointer"""
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF2IF2_Clone(self)

    def SetTargetPoints(self, points):
        r"""
        SetTargetPoints(self, points)

        Parameters
        ----------
        points: itkVectorContainerUILSNF2 *

        """
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF2IF2_SetTargetPoints(self, points)

    def GetTargetPoints(self):
        r"""GetTargetPoints(self) -> itkVectorContainerUILSNF2_Pointer"""
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF2IF2_GetTargetPoints(self)

    def GetReachedTargetPoints(self):
        r"""GetReachedTargetPoints(self) -> itkVectorContainerUILSNF2_Pointer"""
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF2IF2_GetReachedTargetPoints(self)

    def GetGradientImage(self):
        r"""GetGradientImage(self) -> itkImageCVF22_Pointer"""
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF2IF2_GetGradientImage(self)

    def SetGenerateGradientImage(self, _arg):
        r"""
        SetGenerateGradientImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF2IF2_SetGenerateGradientImage(self, _arg)

    def GetGenerateGradientImage(self):
        r"""GetGenerateGradientImage(self) -> bool const &"""
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF2IF2_GetGenerateGradientImage(self)

    def GenerateGradientImageOn(self):
        r"""GenerateGradientImageOn(self)"""
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF2IF2_GenerateGradientImageOn(self)

    def GenerateGradientImageOff(self):
        r"""GenerateGradientImageOff(self)"""
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF2IF2_GenerateGradientImageOff(self)

    def SetTargetOffset(self, _arg):
        r"""
        SetTargetOffset(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF2IF2_SetTargetOffset(self, _arg)

    def GetTargetOffset(self):
        r"""GetTargetOffset(self) -> double const &"""
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF2IF2_GetTargetOffset(self)

    def SetTargetReachedMode(self, _arg):
        r"""
        SetTargetReachedMode(self, _arg)

        Parameters
        ----------
        _arg: enum itkFastMarchingUpwindGradientImageFilterEnums::TargetCondition

        """
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF2IF2_SetTargetReachedMode(self, _arg)

    def GetTargetReachedMode(self):
        r"""GetTargetReachedMode(self) -> itkFastMarchingUpwindGradientImageFilterEnums::TargetCondition const &"""
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF2IF2_GetTargetReachedMode(self)

    def SetTargetReachedModeToNoTargets(self):
        r"""SetTargetReachedModeToNoTargets(self)"""
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF2IF2_SetTargetReachedModeToNoTargets(self)

    def SetTargetReachedModeToOneTarget(self):
        r"""SetTargetReachedModeToOneTarget(self)"""
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF2IF2_SetTargetReachedModeToOneTarget(self)

    def SetTargetReachedModeToSomeTargets(self, numberOfTargets):
        r"""
        SetTargetReachedModeToSomeTargets(self, numberOfTargets)

        Parameters
        ----------
        numberOfTargets: unsigned long

        """
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF2IF2_SetTargetReachedModeToSomeTargets(self, numberOfTargets)

    def SetTargetReachedModeToAllTargets(self):
        r"""SetTargetReachedModeToAllTargets(self)"""
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF2IF2_SetTargetReachedModeToAllTargets(self)

    def GetNumberOfTargets(self):
        r"""GetNumberOfTargets(self) -> unsigned long const &"""
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF2IF2_GetNumberOfTargets(self)

    def GetTargetValue(self):
        r"""GetTargetValue(self) -> double const &"""
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF2IF2_GetTargetValue(self)
    LevelSetDoubleDivisionOperatorsCheck = _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF2IF2_LevelSetDoubleDivisionOperatorsCheck
    
    LevelSetDoubleDivisionAndAssignOperatorsCheck = _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF2IF2_LevelSetDoubleDivisionAndAssignOperatorsCheck
    
    __swig_destroy__ = _itkFastMarchingUpwindGradientImageFilterPython.delete_itkFastMarchingUpwindGradientImageFilterIF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkFastMarchingUpwindGradientImageFilterIF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkFastMarchingUpwindGradientImageFilterIF2IF2

        Create a new object of the class itkFastMarchingUpwindGradientImageFilterIF2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkFastMarchingUpwindGradientImageFilterIF2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkFastMarchingUpwindGradientImageFilterIF2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkFastMarchingUpwindGradientImageFilterIF2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkFastMarchingUpwindGradientImageFilterIF2IF2 in _itkFastMarchingUpwindGradientImageFilterPython:
_itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF2IF2_swigregister(itkFastMarchingUpwindGradientImageFilterIF2IF2)

def itkFastMarchingUpwindGradientImageFilterIF3IF3_New():
    return itkFastMarchingUpwindGradientImageFilterIF3IF3.New()

class itkFastMarchingUpwindGradientImageFilterIF3IF3(itk.itkFastMarchingImageFilterPython.itkFastMarchingImageFilterIF3IF3):
    r"""Proxy of C++ itkFastMarchingUpwindGradientImageFilterIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkFastMarchingUpwindGradientImageFilterIF3IF3_Pointer"""
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkFastMarchingUpwindGradientImageFilterIF3IF3_Pointer"""
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF3IF3_Clone(self)

    def SetTargetPoints(self, points):
        r"""
        SetTargetPoints(self, points)

        Parameters
        ----------
        points: itkVectorContainerUILSNF3 *

        """
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF3IF3_SetTargetPoints(self, points)

    def GetTargetPoints(self):
        r"""GetTargetPoints(self) -> itkVectorContainerUILSNF3_Pointer"""
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF3IF3_GetTargetPoints(self)

    def GetReachedTargetPoints(self):
        r"""GetReachedTargetPoints(self) -> itkVectorContainerUILSNF3_Pointer"""
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF3IF3_GetReachedTargetPoints(self)

    def GetGradientImage(self):
        r"""GetGradientImage(self) -> itkImageCVF33_Pointer"""
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF3IF3_GetGradientImage(self)

    def SetGenerateGradientImage(self, _arg):
        r"""
        SetGenerateGradientImage(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF3IF3_SetGenerateGradientImage(self, _arg)

    def GetGenerateGradientImage(self):
        r"""GetGenerateGradientImage(self) -> bool const &"""
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF3IF3_GetGenerateGradientImage(self)

    def GenerateGradientImageOn(self):
        r"""GenerateGradientImageOn(self)"""
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF3IF3_GenerateGradientImageOn(self)

    def GenerateGradientImageOff(self):
        r"""GenerateGradientImageOff(self)"""
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF3IF3_GenerateGradientImageOff(self)

    def SetTargetOffset(self, _arg):
        r"""
        SetTargetOffset(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF3IF3_SetTargetOffset(self, _arg)

    def GetTargetOffset(self):
        r"""GetTargetOffset(self) -> double const &"""
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF3IF3_GetTargetOffset(self)

    def SetTargetReachedMode(self, _arg):
        r"""
        SetTargetReachedMode(self, _arg)

        Parameters
        ----------
        _arg: enum itkFastMarchingUpwindGradientImageFilterEnums::TargetCondition

        """
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF3IF3_SetTargetReachedMode(self, _arg)

    def GetTargetReachedMode(self):
        r"""GetTargetReachedMode(self) -> itkFastMarchingUpwindGradientImageFilterEnums::TargetCondition const &"""
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF3IF3_GetTargetReachedMode(self)

    def SetTargetReachedModeToNoTargets(self):
        r"""SetTargetReachedModeToNoTargets(self)"""
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF3IF3_SetTargetReachedModeToNoTargets(self)

    def SetTargetReachedModeToOneTarget(self):
        r"""SetTargetReachedModeToOneTarget(self)"""
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF3IF3_SetTargetReachedModeToOneTarget(self)

    def SetTargetReachedModeToSomeTargets(self, numberOfTargets):
        r"""
        SetTargetReachedModeToSomeTargets(self, numberOfTargets)

        Parameters
        ----------
        numberOfTargets: unsigned long

        """
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF3IF3_SetTargetReachedModeToSomeTargets(self, numberOfTargets)

    def SetTargetReachedModeToAllTargets(self):
        r"""SetTargetReachedModeToAllTargets(self)"""
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF3IF3_SetTargetReachedModeToAllTargets(self)

    def GetNumberOfTargets(self):
        r"""GetNumberOfTargets(self) -> unsigned long const &"""
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF3IF3_GetNumberOfTargets(self)

    def GetTargetValue(self):
        r"""GetTargetValue(self) -> double const &"""
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF3IF3_GetTargetValue(self)
    LevelSetDoubleDivisionOperatorsCheck = _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF3IF3_LevelSetDoubleDivisionOperatorsCheck
    
    LevelSetDoubleDivisionAndAssignOperatorsCheck = _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF3IF3_LevelSetDoubleDivisionAndAssignOperatorsCheck
    
    __swig_destroy__ = _itkFastMarchingUpwindGradientImageFilterPython.delete_itkFastMarchingUpwindGradientImageFilterIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkFastMarchingUpwindGradientImageFilterIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkFastMarchingUpwindGradientImageFilterIF3IF3

        Create a new object of the class itkFastMarchingUpwindGradientImageFilterIF3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkFastMarchingUpwindGradientImageFilterIF3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkFastMarchingUpwindGradientImageFilterIF3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkFastMarchingUpwindGradientImageFilterIF3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkFastMarchingUpwindGradientImageFilterIF3IF3 in _itkFastMarchingUpwindGradientImageFilterPython:
_itkFastMarchingUpwindGradientImageFilterPython.itkFastMarchingUpwindGradientImageFilterIF3IF3_swigregister(itkFastMarchingUpwindGradientImageFilterIF3IF3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def fast_marching_upwind_gradient_image_filter(*args: itkt.ImageLike,  target_points=..., generate_gradient_image: bool=..., target_offset: float=..., target_reached_mode=..., target_reached_mode_to_some_targets: int=..., outside_points=..., alive_points=..., trial_points=..., speed_constant: float=..., normalization_factor: float=..., stopping_value: float=..., collect_points: bool=..., output_size: Sequence[int]=..., output_region: itkt.ImageRegion=..., output_spacing: Sequence[float]=..., output_direction=..., output_origin: Sequence[float]=..., override_output_information: bool=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for FastMarchingUpwindGradientImageFilter"""
    import itk

    kwarg_typehints = { 'target_points':target_points,'generate_gradient_image':generate_gradient_image,'target_offset':target_offset,'target_reached_mode':target_reached_mode,'target_reached_mode_to_some_targets':target_reached_mode_to_some_targets,'outside_points':outside_points,'alive_points':alive_points,'trial_points':trial_points,'speed_constant':speed_constant,'normalization_factor':normalization_factor,'stopping_value':stopping_value,'collect_points':collect_points,'output_size':output_size,'output_region':output_region,'output_spacing':output_spacing,'output_direction':output_direction,'output_origin':output_origin,'override_output_information':override_output_information }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.FastMarchingUpwindGradientImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def fast_marching_upwind_gradient_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKFastMarching.FastMarchingUpwindGradientImageFilter
    fast_marching_upwind_gradient_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    fast_marching_upwind_gradient_image_filter.__doc__ = filter_object.__doc__



